Crate tinywasm_types

Crate tinywasm_types 

Types used by tinywasm and tinywasm_parser.

Modules

archive

Structs

Data
Element
Export
A WebAssembly Module Export
ExternRef
FuncRef
FuncType
The type of a WebAssembly Function.
Global
GlobalType
Import
MemoryArg
Represents a memory immediate in a WebAssembly memory instruction.
MemoryType
Represents a memory’s type.
Module
A TinyWasm WebAssembly Module
ModuleExport
A module export descriptor.
ModuleImport
A module import descriptor.
TableType
ValueCounts
WasmFunction
WasmFunctionData

Enums

BinOp
BinOp128
CmpOp
An integer comparison operator, currently only used for conditional jumps.
ConstInstruction
DataKind
ElementItem
ElementKind
ExportType
Exported entity type.
ExternVal
A WebAssembly External Value.
ExternalKind
A WebAssembly External Kind.
ImportKind
ImportType
Imported entity type.
Instruction
A WebAssembly Instruction
LocalMemoryAllocation
How instantiation should prepare local memories declared by the module.
MemoryArch
WasmType
Type of a WebAssembly value.
WasmValue
A WebAssembly value.

Type Aliases

Addr
A WebAssembly Address.
ConstIdx
DataAddr
ElemAddr
ExternAddr
FuncAddr
GlobalAddr
LocalAddr
MemAddr
ModuleInstanceAddr
TableAddr
TypeAddr