LocalMemoryAllocation

Enum LocalMemoryAllocation 

pub enum LocalMemoryAllocation {
    Skip,
    Lazy,
    Eager,
}
How instantiation should prepare local memories declared by the module.

Variants



Skip

The module’s local memories are unobservable and can be skipped entirely.



Lazy

The module’s local memories may be observed through exports, but can be delayed until first use.



Eager

The module’s local memories must be allocated during instantiation.