Types used by tinywasm and tinywasm_parser.
Modules
Structs
- Data
- Element
- Export
- A WebAssembly Module Export
- Extern
Ref - FuncRef
- Func
Type - The type of a WebAssembly Function.
- Global
- Global
Type - Import
- Memory
Arg - Represents a memory immediate in a WebAssembly memory instruction.
- Memory
Type - Represents a memory’s type.
- Module
- A
TinyWasmWebAssembly Module - Module
Export - A module export descriptor.
- Module
Import - A module import descriptor.
- Table
Type - Value
Counts - Wasm
Function - Wasm
Function Data
Enums
- BinOp
- BinOp128
- CmpOp
- An integer comparison operator, currently only used for conditional jumps.
- Const
Instruction - Data
Kind - Element
Item - Element
Kind - Export
Type - Exported entity type.
- Extern
Val - A WebAssembly External Value.
- External
Kind - A WebAssembly External Kind.
- Import
Kind - Import
Type - Imported entity type.
- Instruction
- A WebAssembly Instruction
- Local
Memory Allocation - How instantiation should prepare local memories declared by the module.
- Memory
Arch - Wasm
Type - Type of a WebAssembly value.
- Wasm
Value - A WebAssembly value.